@@ -1,4 +1,4 @@
-# Copyright 2020 Observational Health Data Sciences and Informatics
+# Copyright 2021 Observational Health Data Sciences and Informatics
 #
 # This file is part of SqlRender
 # 
@@ -15,13 +15,14 @@
 # limitations under the License.
 
 #' Launch the SqlRender Developer Shiny app
-#' 
-#' @param launch.browser    Should the app be launched in your default browser, or in a Shiny window.
-#'                          Note: copying to clipboard will not work in a Shiny window.
-#' 
-#' @details 
-#' Launches a Shiny app that allows the user to develop SQL and see how it translates to the supported dialects.
-#' 
+#'
+#' @param launch.browser   Should the app be launched in your default browser, or in a Shiny window.
+#'                         Note: copying to clipboard will not work in a Shiny window.
+#'
+#' @details
+#' Launches a Shiny app that allows the user to develop SQL and see how it translates to the supported
+#' dialects.
+#'
 #' @export
 launchSqlRenderDeveloper <- function(launch.browser = TRUE) {
   ensure_installed("shinydashboard")
@@ -29,19 +30,16 @@ launchSqlRenderDeveloper <- function(launch.browser = TRUE) {
   shiny::runApp(appDir, display.mode = "normal", launch.browser = launch.browser)
 }
 
-# Borrowed from devtools: https://github.com/hadley/devtools/blob/ba7a5a4abd8258c52cb156e7b26bb4bf47a79f0b/R/utils.r#L44
-is_installed <- function (pkg, version = 0) {
-  installed_version <- tryCatch(utils::packageVersion(pkg), 
-                                error = function(e) NA)
+is_installed <- function(pkg, version = 0) {
+  installed_version <- tryCatch(utils::packageVersion(pkg), error = function(e) NA)
   !is.na(installed_version) && installed_version >= version
 }
 
-# Borrowed and adapted from devtools: https://github.com/hadley/devtools/blob/ba7a5a4abd8258c52cb156e7b26bb4bf47a79f0b/R/utils.r#L74
 ensure_installed <- function(pkg) {
   if (!is_installed(pkg)) {
     msg <- paste0(sQuote(pkg), " must be installed for this functionality.")
     if (interactive()) {
-      message(msg, "\nWould you like to install it?")
+      inform(paste(msg, "Would you like to install it?", sep = "\n"))
       if (menu(c("Yes", "No")) == 1) {
         install.packages(pkg)
       } else {
