@@ -150,11 +150,10 @@ test_that("Backslash in parameter is handled correctly", {
 })
 
 test_that("Dollar in parameter is handled correctly", {
-    sql <- render("SELECT * FROM table WHERE name = '@name';", name = "NA$joe")
-    expect_equal(sql, "SELECT * FROM table WHERE name = 'NA$joe';")
+  sql <- render("SELECT * FROM table WHERE name = '@name';", name = "NA$joe")
+  expect_equal(sql, "SELECT * FROM table WHERE name = 'NA$joe';")
 })
 
-
 test_that("If-then-else: error on bad boolean logic syntax", {
   # Note there's only one equals sign:
   expect_error(render("{true = true} ? {true} : {false}"))
@@ -169,3 +168,7 @@ test_that("rendering: no problem when not providing parameters", {
   # Note wrong parameter name:
   expect_equal(render("SELECT * FROM @my_table"), "SELECT * FROM @my_table")
 })
+
+test_that("rendering: warning when using old function", {
+  expect_warning(renderSql("SELECT * FROM @my_table"))
+})
